@@ -35,6 +35,15 @@ Datasets:
 
         ang (degrees): Angle of test to alloy roll direction
 
+    df_ruff: Metal data from Ruff (1984). Columns:
+        part: Part identifier
+
+        TYS: Tensile Yield Stress (ksi), averaged over two coupons
+
+        TUS: Tensile Ultimate Stress (ksi), averaged over two coupons
+
+        thickness: Coupon thickness (in)
+
     df_trajectory_full: Simulated trajectory data. Columns:
 
         t: Time since projectile launch (seconds)
@@ -46,6 +55,9 @@ Datasets:
 References:
     Stang, Greenspan, and Newman, "Poisson's ratio of some structural alloys for
     large strains" (1946) U.S. Department of Commerce National Bureau of Standards
+
+    Ruff, Paul E. An Overview of the MIL-HDBK-5 Program. BATTELLE COLUMBUS DIV
+    OH, 1984.
 """
 
 from .datasets import *
